@@ -106,3 +106,11 @@ def test_undercoordinated_n():
         Structure.from_file(os.path.join(THIS_DIR, "test_files", "mil-53-al-nh2.cif"))
     )
     assert mofchecker.has_undercoordinated_n == True
+
+
+def test_dicts():
+    mofchecker = MOFChecker(
+        Structure.from_file(os.path.join(THIS_DIR, "test_files", "VUGYED_clean.cif"))
+    )
+    assert isinstance(mofchecker.check_descriptions, dict)
+    assert isinstance(mofchecker.check_expected_values, dict)
